==> feather-2.4.5.tar.gz: feather-2.4.5/src/utils/Networking.cpp <==
// SPDX-License-Identifier: BSD-3-Clause
// SPDX-FileCopyrightText: 2020-2023 The Monero Project

#include <QNetworkAccessManager>
#include <QNetworkReply>

#include "utils/Utils.h"
#include "utils/Networking.h"
#include "utils/NetworkManager.h"
#include "config.h"

Networking::Networking(QObject *parent)
    : QObject(parent) {}

void Networking::setUserAgent(const QString &userAgent) {
    this->m_userAgent = userAgent;
}

QNetworkReply* Networking::get(const QString &url) {
    if (config()->get(Config::offlineMode).toBool()) {
        return nullptr;
    }

    m_networkAccessManager = getNetwork(url);

    QNetworkRequest request;
    request.setUrl(QUrl(url));
    request.setRawHeader("User-Agent", m_userAgent.toUtf8());

    return this->m_networkAccessManager->get(request);
}

QNetworkReply* Networking::getJson(const QString &url) {
    if (config()->get(Config::offlineMode).toBool()) {
        return nullptr;
    }

    m_networkAccessManager = getNetwork(url);

    QNetworkRequest request;
    request.setUrl(QUrl(url));
    request.setRawHeader("User-Agent", m_userAgent.toUtf8());
    request.setRawHeader("Content-Type", "application/json");

    return this->m_networkAccessManager->get(request);
}

QNetworkReply* Networking::postJson(const QString &url, const QJsonObject &data) {
    if (config()->get(Config::offlineMode).toBool()) {
        return nullptr;
    }

    m_networkAccessManager = getNetwork(url);

    QNetworkRequest request;
    request.setUrl(QUrl(url));
    request.setRawHeader("User-Agent", m_userAgent.toUtf8());
    request.setRawHeader("Content-Type", "application/json");

    QJsonDocument doc(data);
    QByteArray bytes = doc.toJson();
    return this->m_networkAccessManager->post(request, bytes);
}

==> feather-2.6.0.tar.gz: feather-2.6.0/src/utils/Networking.cpp <==
// SPDX-License-Identifier: BSD-3-Clause
// SPDX-FileCopyrightText: 2020-2023 The Monero Project

#include <QNetworkAccessManager>
#include <QNetworkReply>

#include "utils/Utils.h"
#include "utils/Networking.h"
#include "utils/NetworkManager.h"
#include "config.h"

Networking::Networking(QObject *parent)
    : QObject(parent) {}

void Networking::setUserAgent(const QString &userAgent) {
    this->m_userAgent = userAgent;
}

QNetworkReply* Networking::get(QObject *parent, const QString &url) {
    if (conf()->get(Config::offlineMode).toBool()) {
        return nullptr;
    }

    m_networkAccessManager = getNetwork(url);

    QNetworkRequest request;
    request.setUrl(QUrl(url));
    request.setRawHeader("User-Agent", m_userAgent.toUtf8());

    QNetworkReply *reply = this->m_networkAccessManager->get(request);;
    reply->setParent(parent);
    return reply;
}

QNetworkReply* Networking::getJson(QObject *parent, const QString &url) {
    if (conf()->get(Config::offlineMode).toBool()) {
        return nullptr;
    }

    m_networkAccessManager = getNetwork(url);

    QNetworkRequest request;
    request.setUrl(QUrl(url));
    request.setRawHeader("User-Agent", m_userAgent.toUtf8());
    request.setRawHeader("Content-Type", "application/json");

    QNetworkReply *reply = this->m_networkAccessManager->get(request);
    reply->setParent(parent);
    return reply;
}

QNetworkReply* Networking::postJson(QObject *parent, const QString &url, const QJsonObject &data) {
    if (conf()->get(Config::offlineMode).toBool()) {
        return nullptr;
    }

    m_networkAccessManager = getNetwork(url);

    QNetworkRequest request;
    request.setUrl(QUrl(url));
    request.setRawHeader("User-Agent", m_userAgent.toUtf8());
    request.setRawHeader("Content-Type", "application/json");

    QJsonDocument doc(data);
    QByteArray bytes = doc.toJson();

    QNetworkReply *reply = this->m_networkAccessManager->post(request, bytes);
    reply->setParent(parent);
    return reply;
}
